@@ -29,16 +29,34 @@ class XORHasher:
             
         return sequence
 
-def decrypt_columns(df, columns=[]):
+def decrypt_columns(df, columns=None):
     
+    if columns is None:
+        columns = df.columns
+        
+    if isinstance(columns, str):
+        columns = [columns]
+        
+    if not isinstance(columns, list):
+        raise Exception("Expecting columns to be a list.")
+        
     hh = XORHasher('SB-Humai-Fernet-Key-ABCDEFGHIJKL')
     
     hu.columns_as_str(df, columns=columns)
     for c in columns:
         df.loc[:,c] = df[c].apply(lambda x: hh.decrypt(x)) 
 
-def encrypt_columns(df, columns=[]):
+def encrypt_columns(df, columns=None):
     
+    if columns is None:
+        columns = df.columns
+        
+    if isinstance(columns, str):
+        columns = [columns]
+        
+    if not isinstance(columns, list):
+        raise Exception("Expecting columns to be a list.")
+        
     hh = XORHasher('SB-Humai-Fernet-Key-ABCDEFGHIJKL')
     
     hu.columns_as_str(df, columns=columns)
